ListCapacityReservationsFluentBuilder

Struct ListCapacityReservationsFluentBuilder 

pub struct ListCapacityReservationsFluentBuilder { /* private fields */ }
Fluent builder constructing a request to ListCapacityReservations.

Lists the capacity reservations for the current account.

Implementations

Source

impl ListCapacityReservationsFluentBuilder

pub fn as_input(&self) -> &ListCapacityReservationsInputBuilder

Access the ListCapacityReservations as a reference.

pub async fn send( self, ) -> Result<ListCapacityReservationsOutput, SdkError<ListCapacityReservationsError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<ListCapacityReservationsOutput, ListCapacityReservationsError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn into_paginator(self) -> ListCapacityReservationsPaginator

Create a paginator for this request

Paginators are used by calling send().await which returns a PaginationStream.

pub fn next_token(self, input: impl Into<String>) -> Self

A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated.

pub fn set_next_token(self, input: Option<String>) -> Self

A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated.

pub fn get_next_token(&self) -> &Option<String>

A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated.

pub fn max_results(self, input: i32) -> Self

Specifies the maximum number of results to return.

pub fn set_max_results(self, input: Option<i32>) -> Self

Specifies the maximum number of results to return.

pub fn get_max_results(&self) -> &Option<i32>

Specifies the maximum number of results to return.