#[non_exhaustive]pub struct ListCapacityReservationsInputBuilder { /* private fields */ }Expand description
A builder for ListCapacityReservationsInput.
Implementations
Sourceimpl ListCapacityReservationsInputBuilder
impl ListCapacityReservationsInputBuilder
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
Specifies the maximum number of results to return.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
Specifies the maximum number of results to return.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
Specifies the maximum number of results to return.
Sourcepub fn build(self) -> Result<ListCapacityReservationsInput, BuildError>
pub fn build(self) -> Result<ListCapacityReservationsInput, BuildError>
Consumes the builder and constructs a ListCapacityReservationsInput.
Sourceimpl ListCapacityReservationsInputBuilder
impl ListCapacityReservationsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListCapacityReservationsOutput, SdkError<ListCapacityReservationsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListCapacityReservationsOutput, SdkError<ListCapacityReservationsError, HttpResponse>>
Sends a request with this input using the given client.