#[non_exhaustive]pub struct ListCapacityReservationsOutputBuilder { /* private fields */ }Expand description
A builder for ListCapacityReservationsOutput.
Implementations
Sourceimpl ListCapacityReservationsOutputBuilder
impl ListCapacityReservationsOutputBuilder
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn capacity_reservations(self, input: CapacityReservation) -> Self
pub fn capacity_reservations(self, input: CapacityReservation) -> Self
Appends an item to capacity_reservations.
To override the contents of this collection use set_capacity_reservations.
The capacity reservations for the current account.
Sourcepub fn set_capacity_reservations(
self,
input: Option<Vec<CapacityReservation>>,
) -> Self
pub fn set_capacity_reservations( self, input: Option<Vec<CapacityReservation>>, ) -> Self
The capacity reservations for the current account.
Sourcepub fn get_capacity_reservations(&self) -> &Option<Vec<CapacityReservation>>
pub fn get_capacity_reservations(&self) -> &Option<Vec<CapacityReservation>>
The capacity reservations for the current account.
Sourcepub fn build(self) -> Result<ListCapacityReservationsOutput, BuildError>
pub fn build(self) -> Result<ListCapacityReservationsOutput, BuildError>
Consumes the builder and constructs a ListCapacityReservationsOutput.
This method will fail if any of the following fields are not set: