pub struct ListCapacityReservationsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListCapacityReservations.
Lists the capacity reservations for the current account.
Implementations
Sourceimpl ListCapacityReservationsFluentBuilder
impl ListCapacityReservationsFluentBuilder
Sourcepub fn as_input(&self) -> &ListCapacityReservationsInputBuilder
pub fn as_input(&self) -> &ListCapacityReservationsInputBuilder
Access the ListCapacityReservations as a reference.
Sourcepub async fn send(
self,
) -> Result<ListCapacityReservationsOutput, SdkError<ListCapacityReservationsError, HttpResponse>>
pub async fn send( self, ) -> Result<ListCapacityReservationsOutput, SdkError<ListCapacityReservationsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListCapacityReservationsOutput, ListCapacityReservationsError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListCapacityReservationsOutput, ListCapacityReservationsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn into_paginator(self) -> ListCapacityReservationsPaginator
pub fn into_paginator(self) -> ListCapacityReservationsPaginator
Create a paginator for this request
Paginators are used by calling send().await which returns a PaginationStream.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
Specifies the maximum number of results to return.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
Specifies the maximum number of results to return.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
Specifies the maximum number of results to return.